"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def test(hub, ctx, replication_group_id: str, node_group_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Represents the input of a TestFailover operation which test automatic failover on a specified node group (called shard in the console) in a replication group (called cluster in the console).  Note the following    A customer can use this operation to test automatic failover on up to 5 shards (called node groups in the ElastiCache API and AWS CLI) in any rolling 24-hour period.   If calling this operation on shards in different clusters (called replication groups in the API and CLI), the calls can be made concurrently.     If calling this operation multiple times on different shards in the same Redis (cluster mode enabled) replication group, the first node replacement must complete before a subsequent call can be made.   To determine whether the node replacement is complete you can check Events using the Amazon ElastiCache console, the AWS CLI, or the ElastiCache API. Look for the following automatic failover related events, listed here in order of occurrance:   Replication group message: Test Failover API called for node group <node-group-id>    Cache cluster message: Failover from primary node <primary-node-id> to replica node <node-id> completed    Replication group message: Failover from primary node <primary-node-id> to replica node <node-id> completed    Cache cluster message: Recovering cache nodes <node-id>    Cache cluster message: Finished recovery for cache nodes <node-id>    For more information see:    Viewing ElastiCache Events in the ElastiCache User Guide     DescribeEvents in the ElastiCache API Reference     Also see, Testing Multi-AZ  in the ElastiCache User Guide.

    Args:
        replication_group_id(str): The name of the replication group (console: cluster) whose automatic failover is being tested by this operation.
        node_group_id(str): The name of the node group (called shard in the console) in this replication group on which automatic failover is to be tested. You may test automatic failover on up to 5 node groups in any rolling 24-hour period.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticache.failover.test(
                ctx, replication_group_id=value, node_group_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticache.failover.test replication_group_id=value, node_group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticache",
        operation="test_failover",
        op_kwargs={
            "ReplicationGroupId": replication_group_id,
            "NodeGroupId": node_group_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def allocate(
    hub,
    ctx,
    availability_zone: str,
    quantity: int,
    auto_placement: str = None,
    client_token: str = None,
    instance_type: str = None,
    instance_family: str = None,
    tag_specifications: List = None,
    host_recovery: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Allocates a Dedicated Host to your account. At a minimum, specify the supported instance type or instance family, the Availability Zone in which to allocate the host, and the number of hosts to allocate.

    Args:
        auto_placement(str, optional): Indicates whether the host accepts any untargeted instance launches that match its instance type configuration, or if it only accepts Host tenancy instance launches that specify its unique host ID. For more information, see  Understanding auto-placement and affinity in the Amazon EC2 User Guide. Default: on . Defaults to None.
        availability_zone(str): The Availability Zone in which to allocate the Dedicated Host.
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring Idempotency. Defaults to None.
        instance_type(str, optional): Specifies the instance type to be supported by the Dedicated Hosts. If you specify an instance type, the Dedicated Hosts support instances of the specified instance type only. If you want the Dedicated Hosts to support multiple instance types in a specific instance family, omit this parameter and specify InstanceFamily instead. You cannot specify InstanceType and InstanceFamily in the same request. Defaults to None.
        instance_family(str, optional): Specifies the instance family to be supported by the Dedicated Hosts. If you specify an instance family, the Dedicated Hosts support multiple instance types within that instance family. If you want the Dedicated Hosts to support a specific instance type only, omit this parameter and specify InstanceType instead. You cannot specify InstanceFamily and InstanceType in the same request. Defaults to None.
        quantity(int): The number of Dedicated Hosts to allocate to your account with these parameters.
        tag_specifications(List, optional): The tags to apply to the Dedicated Host during creation. Defaults to None.
        host_recovery(str, optional): Indicates whether to enable or disable host recovery for the Dedicated Host. Host recovery is disabled by default. For more information, see  Host recovery in the Amazon EC2 User Guide. Default: off . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.host.init.allocate(
                ctx, availability_zone=value, quantity=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.host.init.allocate availability_zone=value, quantity=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="allocate_hosts",
        op_kwargs={
            "AutoPlacement": auto_placement,
            "AvailabilityZone": availability_zone,
            "ClientToken": client_token,
            "InstanceType": instance_type,
            "InstanceFamily": instance_family,
            "Quantity": quantity,
            "TagSpecifications": tag_specifications,
            "HostRecovery": host_recovery,
        },
    )


async def describe_all(
    hub,
    ctx,
    filter_: List = None,
    host_ids: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified Dedicated Hosts or all your Dedicated Hosts. The results describe only the Dedicated Hosts in the Region you're currently using. All listed instances consume capacity on your Dedicated Host. Dedicated Hosts that have recently been released are listed with the state released.

    Args:
        filter_(List, optional): The filters.    auto-placement - Whether auto-placement is enabled or disabled (on | off).    availability-zone - The Availability Zone of the host.    client-token - The idempotency token that you provided when you allocated the host.    host-reservation-id - The ID of the reservation assigned to this host.    instance-type - The instance type size that the Dedicated Host is configured to support.    state - The allocation state of the Dedicated Host (available | under-assessment | permanent-failure | released | released-permanent-failure).    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.  . Defaults to None.
        host_ids(List, optional): The IDs of the Dedicated Hosts. The IDs are used for targeted instance launches. Defaults to None.
        max_results(int, optional): The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the returned nextToken value. This value can be between 5 and 500. If maxResults is given a larger value than 500, you receive an error. You cannot specify this parameter and the host IDs parameter in the same request. Defaults to None.
        next_token(str, optional): The token to use to retrieve the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.host.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.host.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_hosts",
        op_kwargs={
            "Filter": filter_,
            "HostIds": host_ids,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def modify(
    hub,
    ctx,
    host_ids: List,
    auto_placement: str = None,
    host_recovery: str = None,
    instance_type: str = None,
    instance_family: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modify the auto-placement setting of a Dedicated Host. When auto-placement is enabled, any instances that you launch with a tenancy of host but without a specific host ID are placed onto any available Dedicated Host in your account that has auto-placement enabled. When auto-placement is disabled, you need to provide a host ID to have the instance launch onto a specific host. If no host ID is provided, the instance is launched onto a suitable host with auto-placement enabled. You can also use this API action to modify a Dedicated Host to support either multiple instance types in an instance family, or to support a specific instance type only.

    Args:
        auto_placement(str, optional): Specify whether to enable or disable auto-placement. Defaults to None.
        host_ids(List): The IDs of the Dedicated Hosts to modify.
        host_recovery(str, optional): Indicates whether to enable or disable host recovery for the Dedicated Host. For more information, see  Host recovery in the Amazon EC2 User Guide. Defaults to None.
        instance_type(str, optional): Specifies the instance type to be supported by the Dedicated Host. Specify this parameter to modify a Dedicated Host to support only a specific instance type. If you want to modify a Dedicated Host to support multiple instance types in its current instance family, omit this parameter and specify InstanceFamily instead. You cannot specify InstanceType and InstanceFamily in the same request. Defaults to None.
        instance_family(str, optional): Specifies the instance family to be supported by the Dedicated Host. Specify this parameter to modify a Dedicated Host to support multiple instance types within its current instance family. If you want to modify a Dedicated Host to support a specific instance type only, omit this parameter and specify InstanceType instead. You cannot specify InstanceFamily and InstanceType in the same request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.host.init.modify(ctx, host_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.host.init.modify host_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_hosts",
        op_kwargs={
            "AutoPlacement": auto_placement,
            "HostIds": host_ids,
            "HostRecovery": host_recovery,
            "InstanceType": instance_type,
            "InstanceFamily": instance_family,
        },
    )


async def release(hub, ctx, host_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    When you no longer want to use an On-Demand Dedicated Host it can be released. On-Demand billing is stopped and the host goes into released state. The host ID of Dedicated Hosts that have been released can no longer be specified in another request, for example, to modify the host. You must stop or terminate all instances on a host before it can be released. When Dedicated Hosts are released, it may take some time for them to stop counting toward your limit and you may receive capacity errors when trying to allocate new Dedicated Hosts. Wait a few minutes and then try again. Released hosts still appear in a DescribeHosts response.

    Args:
        host_ids(List): The IDs of the Dedicated Hosts to release.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.host.init.release(ctx, host_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.host.init.release host_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="release_hosts",
        op_kwargs={"HostIds": host_ids},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def put_multiple(
    hub, ctx, configuration_set_name: str, sending_enabled: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Enable or disable email sending for messages that use a particular configuration set in a specific AWS Region.

    Args:
        configuration_set_name(str): The name of the configuration set that you want to enable or disable email sending for.
        sending_enabled(bool, optional): If true, email sending is enabled for the configuration set. If false, email sending is disabled for the configuration set. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.configuration_set_.sending_option.put_multiple(
                ctx, configuration_set_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.configuration_set_.sending_option.put_multiple configuration_set_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="put_configuration_set_sending_options",
        op_kwargs={
            "ConfigurationSetName": configuration_set_name,
            "SendingEnabled": sending_enabled,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    relational_database_name: str,
    relational_database_blueprint_id: str,
    relational_database_bundle_id: str,
    master_database_name: str,
    master_username: str,
    availability_zone: str = None,
    master_user_password: str = None,
    preferred_backup_window: str = None,
    preferred_maintenance_window: str = None,
    publicly_accessible: bool = None,
    tags: List = None,
) -> Dict:
    r'''
    **Autogenerated function**

    Creates a new database in Amazon Lightsail. The create relational database operation supports tag-based access control via request tags. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        relational_database_name(str): The name to use for your new Lightsail database resource. Constraints:   Must contain from 2 to 255 alphanumeric characters, or hyphens.   The first and last character must be a letter or number.  .
        availability_zone(str, optional): The Availability Zone in which to create your new database. Use the us-east-2a case-sensitive format. You can get a list of Availability Zones by using the get regions operation. Be sure to add the include relational database Availability Zones parameter to your request. Defaults to None.
        relational_database_blueprint_id(str): The blueprint ID for your new database. A blueprint describes the major engine version of a database. You can get a list of database blueprints IDs by using the get relational database blueprints operation.
        relational_database_bundle_id(str): The bundle ID for your new database. A bundle describes the performance specifications for your database. You can get a list of database bundle IDs by using the get relational database bundles operation.
        master_database_name(str): The meaning of this parameter differs according to the database engine you use.  MySQL  The name of the database to create when the Lightsail database resource is created. If this parameter isn't specified, no database is created in the database resource. Constraints:   Must contain 1 to 64 letters or numbers.   Must begin with a letter. Subsequent characters can be letters, underscores, or digits (0- 9).   Can't be a word reserved by the specified database engine. For more information about reserved words in MySQL, see the Keywords and Reserved Words articles for MySQL 5.6, MySQL 5.7, and MySQL 8.0.    PostgreSQL  The name of the database to create when the Lightsail database resource is created. If this parameter isn't specified, a database named postgres is created in the database resource. Constraints:   Must contain 1 to 63 letters or numbers.   Must begin with a letter. Subsequent characters can be letters, underscores, or digits (0- 9).   Can't be a word reserved by the specified database engine. For more information about reserved words in PostgreSQL, see the SQL Key Words articles for PostgreSQL 9.6, PostgreSQL 10, PostgreSQL 11, and PostgreSQL 12.  .
        master_username(str): The name for the master user.  MySQL  Constraints:   Required for MySQL.   Must be 1 to 16 letters or numbers. Can contain underscores.   First character must be a letter.   Can't be a reserved word for the chosen database engine. For more information about reserved words in MySQL 5.6 or 5.7, see the Keywords and Reserved Words articles for MySQL 5.6, MySQL 5.7, or MySQL 8.0.    PostgreSQL  Constraints:   Required for PostgreSQL.   Must be 1 to 63 letters or numbers. Can contain underscores.   First character must be a letter.   Can't be a reserved word for the chosen database engine. For more information about reserved words in MySQL 5.6 or 5.7, see the Keywords and Reserved Words articles for PostgreSQL 9.6, PostgreSQL 10, PostgreSQL 11, and PostgreSQL 12.  .
        master_user_password(str, optional): The password for the master user. The password can include any printable ASCII character except "/", """, or "@". It cannot contain spaces.  MySQL  Constraints: Must contain from 8 to 41 characters.  PostgreSQL  Constraints: Must contain from 8 to 128 characters. Defaults to None.
        preferred_backup_window(str, optional): The daily time range during which automated backups are created for your new database if automated backups are enabled. The default is a 30-minute window selected at random from an 8-hour block of time for each AWS Region. For more information about the preferred backup window time blocks for each region, see the Working With Backups guide in the Amazon Relational Database Service (Amazon RDS) documentation. Constraints:   Must be in the hh24:mi-hh24:mi format. Example: 16:00-16:30    Specified in Coordinated Universal Time (UTC).   Must not conflict with the preferred maintenance window.   Must be at least 30 minutes.  . Defaults to None.
        preferred_maintenance_window(str, optional): The weekly time range during which system maintenance can occur on your new database. The default is a 30-minute window selected at random from an 8-hour block of time for each AWS Region, occurring on a random day of the week. Constraints:   Must be in the ddd:hh24:mi-ddd:hh24:mi format.   Valid days: Mon, Tue, Wed, Thu, Fri, Sat, Sun.   Must be at least 30 minutes.   Specified in Coordinated Universal Time (UTC).   Example: Tue:17:00-Tue:17:30   . Defaults to None.
        publicly_accessible(bool, optional): Specifies the accessibility options for your new database. A value of true specifies a database that is available to resources outside of your Lightsail account. A value of false specifies a database that is available only to your Lightsail resources in the same region as your database. Defaults to None.
        tags(List, optional): The tag keys and optional values to add to the resource during create. Use the TagResource action to tag a resource after it's created. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.relational_database.init.create(
                ctx,
                relational_database_name=value,
                relational_database_blueprint_id=value,
                relational_database_bundle_id=value,
                master_database_name=value,
                master_username=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.relational_database.init.create relational_database_name=value, relational_database_blueprint_id=value, relational_database_bundle_id=value, master_database_name=value, master_username=value
    '''
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="create_relational_database",
        op_kwargs={
            "relationalDatabaseName": relational_database_name,
            "availabilityZone": availability_zone,
            "relationalDatabaseBlueprintId": relational_database_blueprint_id,
            "relationalDatabaseBundleId": relational_database_bundle_id,
            "masterDatabaseName": master_database_name,
            "masterUsername": master_username,
            "masterUserPassword": master_user_password,
            "preferredBackupWindow": preferred_backup_window,
            "preferredMaintenanceWindow": preferred_maintenance_window,
            "publiclyAccessible": publicly_accessible,
            "tags": tags,
        },
    )


async def delete(
    hub,
    ctx,
    relational_database_name: str,
    skip_final_snapshot: bool = None,
    final_relational_database_snapshot_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a database in Amazon Lightsail. The delete relational database operation supports tag-based access control via resource tags applied to the resource identified by relationalDatabaseName. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        relational_database_name(str): The name of the database that you are deleting.
        skip_final_snapshot(bool, optional): Determines whether a final database snapshot is created before your database is deleted. If true is specified, no database snapshot is created. If false is specified, a database snapshot is created before your database is deleted. You must specify the final relational database snapshot name parameter if the skip final snapshot parameter is false. Default: false . Defaults to None.
        final_relational_database_snapshot_name(str, optional): The name of the database snapshot created if skip final snapshot is false, which is the default value for that parameter.  Specifying this parameter and also specifying the skip final snapshot parameter to true results in an error.  Constraints:   Must contain from 2 to 255 alphanumeric characters, or hyphens.   The first and last character must be a letter or number.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.relational_database.init.delete(
                ctx, relational_database_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.relational_database.init.delete relational_database_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="delete_relational_database",
        op_kwargs={
            "relationalDatabaseName": relational_database_name,
            "skipFinalSnapshot": skip_final_snapshot,
            "finalRelationalDatabaseSnapshotName": final_relational_database_snapshot_name,
        },
    )


async def get(hub, ctx, relational_database_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a specific database in Amazon Lightsail.

    Args:
        relational_database_name(str): The name of the database that you are looking up.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.relational_database.init.get(
                ctx, relational_database_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.relational_database.init.get relational_database_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_relational_database",
        op_kwargs={"relationalDatabaseName": relational_database_name},
    )


async def get_all(hub, ctx, page_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about all of your databases in Amazon Lightsail.

    Args:
        page_token(str, optional): The token to advance to the next page of results from your request. To get a page token, perform an initial GetRelationalDatabases request. If your results are paginated, the response will return a next page token that you can specify as the page token in a subsequent request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.relational_database.init.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.relational_database.init.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="get_relational_databases",
        op_kwargs={"pageToken": page_token},
    )


async def reboot(hub, ctx, relational_database_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Restarts a specific database in Amazon Lightsail. The reboot relational database operation supports tag-based access control via resource tags applied to the resource identified by relationalDatabaseName. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        relational_database_name(str): The name of your database to reboot.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.relational_database.init.reboot(
                ctx, relational_database_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.relational_database.init.reboot relational_database_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="reboot_relational_database",
        op_kwargs={"relationalDatabaseName": relational_database_name},
    )


async def start(hub, ctx, relational_database_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Starts a specific database from a stopped state in Amazon Lightsail. To restart a database, use the reboot relational database operation. The start relational database operation supports tag-based access control via resource tags applied to the resource identified by relationalDatabaseName. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        relational_database_name(str): The name of your database to start.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.relational_database.init.start(
                ctx, relational_database_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.relational_database.init.start relational_database_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="start_relational_database",
        op_kwargs={"relationalDatabaseName": relational_database_name},
    )


async def stop(
    hub,
    ctx,
    relational_database_name: str,
    relational_database_snapshot_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Stops a specific database that is currently running in Amazon Lightsail. The stop relational database operation supports tag-based access control via resource tags applied to the resource identified by relationalDatabaseName. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        relational_database_name(str): The name of your database to stop.
        relational_database_snapshot_name(str, optional): The name of your new database snapshot to be created before stopping your database. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.relational_database.init.stop(
                ctx, relational_database_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.relational_database.init.stop relational_database_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="stop_relational_database",
        op_kwargs={
            "relationalDatabaseName": relational_database_name,
            "relationalDatabaseSnapshotName": relational_database_snapshot_name,
        },
    )


async def update(
    hub,
    ctx,
    relational_database_name: str,
    master_user_password: str = None,
    rotate_master_user_password: bool = None,
    preferred_backup_window: str = None,
    preferred_maintenance_window: str = None,
    enable_backup_retention: bool = None,
    disable_backup_retention: bool = None,
    publicly_accessible: bool = None,
    apply_immediately: bool = None,
    ca_certificate_identifier: str = None,
) -> Dict:
    r'''
    **Autogenerated function**

    Allows the update of one or more attributes of a database in Amazon Lightsail. Updates are applied immediately, or in cases where the updates could result in an outage, are applied during the database's predefined maintenance window. The update relational database operation supports tag-based access control via resource tags applied to the resource identified by relationalDatabaseName. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        relational_database_name(str): The name of your Lightsail database resource to update.
        master_user_password(str, optional): The password for the master user. The password can include any printable ASCII character except "/", """, or "@". MySQL  Constraints: Must contain from 8 to 41 characters.  PostgreSQL  Constraints: Must contain from 8 to 128 characters. Defaults to None.
        rotate_master_user_password(bool, optional): When true, the master user password is changed to a new strong password generated by Lightsail. Use the get relational database master user password operation to get the new password. Defaults to None.
        preferred_backup_window(str, optional): The daily time range during which automated backups are created for your database if automated backups are enabled. Constraints:   Must be in the hh24:mi-hh24:mi format. Example: 16:00-16:30    Specified in Coordinated Universal Time (UTC).   Must not conflict with the preferred maintenance window.   Must be at least 30 minutes.  . Defaults to None.
        preferred_maintenance_window(str, optional): The weekly time range during which system maintenance can occur on your database. The default is a 30-minute window selected at random from an 8-hour block of time for each AWS Region, occurring on a random day of the week. Constraints:   Must be in the ddd:hh24:mi-ddd:hh24:mi format.   Valid days: Mon, Tue, Wed, Thu, Fri, Sat, Sun.   Must be at least 30 minutes.   Specified in Coordinated Universal Time (UTC).   Example: Tue:17:00-Tue:17:30   . Defaults to None.
        enable_backup_retention(bool, optional): When true, enables automated backup retention for your database. Updates are applied during the next maintenance window because this can result in an outage. Defaults to None.
        disable_backup_retention(bool, optional): When true, disables automated backup retention for your database. Disabling backup retention deletes all automated database backups. Before disabling this, you may want to create a snapshot of your database using the create relational database snapshot operation. Updates are applied during the next maintenance window because this can result in an outage. Defaults to None.
        publicly_accessible(bool, optional): Specifies the accessibility options for your database. A value of true specifies a database that is available to resources outside of your Lightsail account. A value of false specifies a database that is available only to your Lightsail resources in the same region as your database. Defaults to None.
        apply_immediately(bool, optional): When true, applies changes immediately. When false, applies changes during the preferred maintenance window. Some changes may cause an outage. Default: false . Defaults to None.
        ca_certificate_identifier(str, optional): Indicates the certificate that needs to be associated with the database. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.relational_database.init.update(
                ctx, relational_database_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.relational_database.init.update relational_database_name=value
    '''
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="update_relational_database",
        op_kwargs={
            "relationalDatabaseName": relational_database_name,
            "masterUserPassword": master_user_password,
            "rotateMasterUserPassword": rotate_master_user_password,
            "preferredBackupWindow": preferred_backup_window,
            "preferredMaintenanceWindow": preferred_maintenance_window,
            "enableBackupRetention": enable_backup_retention,
            "disableBackupRetention": disable_backup_retention,
            "publiclyAccessible": publicly_accessible,
            "applyImmediately": apply_immediately,
            "caCertificateIdentifier": ca_certificate_identifier,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, group_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the current configuration for the CA used by the group.

    Args:
        group_id(str): The ID of the Greengrass group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.group.certificate.configuration.get(
                ctx, group_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.group.certificate.configuration.get group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="get_group_certificate_configuration",
        op_kwargs={"GroupId": group_id},
    )


async def update(
    hub, ctx, group_id: str, certificate_expiry_in_milliseconds: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the Certificate expiry time for a group.

    Args:
        certificate_expiry_in_milliseconds(str, optional): The amount of time remaining before the certificate expires, in milliseconds. Defaults to None.
        group_id(str): The ID of the Greengrass group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.greengrass.group.certificate.configuration.update(
                ctx, group_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.greengrass.group.certificate.configuration.update group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="greengrass",
        operation="update_group_certificate_configuration",
        op_kwargs={
            "CertificateExpiryInMilliseconds": certificate_expiry_in_milliseconds,
            "GroupId": group_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(
    hub,
    ctx,
    mapping: List,
    source: Dict,
    sinks: List = None,
    location: Dict = None,
    language: str = None,
    additional_plan_options_map: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets code to perform a specified mapping.

    Args:
        mapping(List): The list of mappings from a source table to target tables.
        source(Dict): The source table.
        sinks(List, optional): The target tables. Defaults to None.
        location(Dict, optional): The parameters for the mapping. Defaults to None.
        language(str, optional): The programming language of the code to perform the mapping. Defaults to None.
        additional_plan_options_map(Dict, optional): A map to hold additional optional key-value parameters. Currently, these key-value pairs are supported:    inferSchema  —  Specifies whether to set inferSchema to true or false for the default script generated by an Glue job. For example, to set inferSchema to true, pass the following key value pair:  --additional-plan-options-map '{"inferSchema":"true"}'   . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.plan.get(ctx, mapping=value, source=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.plan.get mapping=value, source=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_plan",
        op_kwargs={
            "Mapping": mapping,
            "Source": source,
            "Sinks": sinks,
            "Location": location,
            "Language": language,
            "AdditionalPlanOptionsMap": additional_plan_options_map,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe_all(
    hub, ctx, filters: List = None, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all patches eligible to be included in a patch baseline.

    Args:
        filters(List, optional): Each element in the array is a structure containing a key-value pair.  Windows Server  Supported keys for Windows Server instance patches include the following:     PATCH_SET   Sample values: OS | APPLICATION      PRODUCT   Sample values: WindowsServer2012 | Office 2010 | MicrosoftDefenderAntivirus      PRODUCT_FAMILY   Sample values: Windows | Office      MSRC_SEVERITY   Sample values: ServicePacks | Important | Moderate      CLASSIFICATION   Sample values: ServicePacks | SecurityUpdates | DefinitionUpdates      PATCH_ID   Sample values: KB123456 | KB4516046     Linux   When specifying filters for Linux patches, you must specify a key-pair for PRODUCT. For example, using the Command Line Interface (CLI), the following command fails:  aws ssm describe-available-patches --filters Key=CVE_ID,Values=CVE-2018-3615  However, the following command succeeds:  aws ssm describe-available-patches --filters Key=PRODUCT,Values=AmazonLinux2018.03 Key=CVE_ID,Values=CVE-2018-3615   Supported keys for Linux instance patches include the following:     PRODUCT   Sample values: AmazonLinux2018.03 | AmazonLinux2.0      NAME   Sample values: kernel-headers | samba-python | php      SEVERITY   Sample values: Critical | Important | Medium | Low      EPOCH   Sample values: 0 | 1      VERSION   Sample values: 78.6.1 | 4.10.16      RELEASE   Sample values: 9.56.amzn1 | 1.amzn2      ARCH   Sample values: i686 | x86_64      REPOSITORY   Sample values: Core | Updates      ADVISORY_ID   Sample values: ALAS-2018-1058 | ALAS2-2021-1594      CVE_ID   Sample values: CVE-2018-3615 | CVE-2020-1472      BUGZILLA_ID   Sample values: 1463241   . Defaults to None.
        max_results(int, optional): The maximum number of patches to return (per page). Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.available_patch.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.available_patch.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="describe_available_patches",
        op_kwargs={
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def verify(hub, ctx, email_address: str) -> None:
    r"""
    **Autogenerated function**

    Deprecated. Use the VerifyEmailIdentity operation to verify a new email address.

    Args:
        email_address(str): The email address to be verified.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.email.address.verify(ctx, email_address=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.email.address.verify email_address=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="verify_email_address",
        op_kwargs={"EmailAddress": email_address},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub, ctx, fpga_image_id: str, attribute: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified attribute of the specified Amazon FPGA Image (AFI).

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        fpga_image_id(str): The ID of the AFI.
        attribute(str): The AFI attribute.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.fpga_image.attribute.describe(
                ctx, fpga_image_id=value, attribute=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.fpga_image.attribute.describe fpga_image_id=value, attribute=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_fpga_image_attribute",
        op_kwargs={
            "DryRun": dry_run,
            "FpgaImageId": fpga_image_id,
            "Attribute": attribute,
        },
    )


async def modify(
    hub,
    ctx,
    fpga_image_id: str,
    dry_run: bool = None,
    attribute: str = None,
    operation_type: str = None,
    user_ids: List = None,
    user_groups: List = None,
    product_codes: List = None,
    load_permission: Dict = None,
    description: str = None,
    name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the specified attribute of the specified Amazon FPGA Image (AFI).

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        fpga_image_id(str): The ID of the AFI.
        attribute(str, optional): The name of the attribute. Defaults to None.
        operation_type(str, optional): The operation type. Defaults to None.
        user_ids(List, optional): The AWS account IDs. This parameter is valid only when modifying the loadPermission attribute. Defaults to None.
        user_groups(List, optional): The user groups. This parameter is valid only when modifying the loadPermission attribute. Defaults to None.
        product_codes(List, optional): The product codes. After you add a product code to an AFI, it can't be removed. This parameter is valid only when modifying the productCodes attribute. Defaults to None.
        load_permission(Dict, optional): The load permission for the AFI. Defaults to None.
        description(str, optional): A description for the AFI. Defaults to None.
        name(str, optional): A name for the AFI. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.fpga_image.attribute.modify(ctx, fpga_image_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.fpga_image.attribute.modify fpga_image_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_fpga_image_attribute",
        op_kwargs={
            "DryRun": dry_run,
            "FpgaImageId": fpga_image_id,
            "Attribute": attribute,
            "OperationType": operation_type,
            "UserIds": user_ids,
            "UserGroups": user_groups,
            "ProductCodes": product_codes,
            "LoadPermission": load_permission,
            "Description": description,
            "Name": name,
        },
    )


async def reset(
    hub, ctx, fpga_image_id: str, dry_run: bool = None, attribute: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Resets the specified attribute of the specified Amazon FPGA Image (AFI) to its default value. You can only reset the load permission attribute.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        fpga_image_id(str): The ID of the AFI.
        attribute(str, optional): The attribute. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.fpga_image.attribute.reset(ctx, fpga_image_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.fpga_image.attribute.reset fpga_image_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="reset_fpga_image_attribute",
        op_kwargs={
            "DryRun": dry_run,
            "FpgaImageId": fpga_image_id,
            "Attribute": attribute,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def put(
    hub,
    ctx,
    auto_scaling_group_name: str,
    policy_name: str,
    policy_type: str = None,
    adjustment_type: str = None,
    min_adjustment_step: int = None,
    min_adjustment_magnitude: int = None,
    scaling_adjustment: int = None,
    cooldown: int = None,
    metric_aggregation_type: str = None,
    step_adjustments: List = None,
    estimated_instance_warmup: int = None,
    target_tracking_configuration: Dict = None,
    enabled: bool = None,
    predictive_scaling_configuration: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates or updates a scaling policy for an Auto Scaling group. Scaling policies are used to scale an Auto Scaling group based on configurable metrics. If no policies are defined, the dynamic scaling and predictive scaling features are not used.  For more information about using dynamic scaling, see Target tracking scaling policies and Step and simple scaling policies in the Amazon EC2 Auto Scaling User Guide. For more information about using predictive scaling, see Predictive scaling for Amazon EC2 Auto Scaling in the Amazon EC2 Auto Scaling User Guide. You can view the scaling policies for an Auto Scaling group using the DescribePolicies API call. If you are no longer using a scaling policy, you can delete it by calling the DeletePolicy API.

    Args:
        auto_scaling_group_name(str): The name of the Auto Scaling group.
        policy_name(str): The name of the policy.
        policy_type(str, optional): One of the following policy types:     TargetTrackingScaling     StepScaling     SimpleScaling (default)    PredictiveScaling   . Defaults to None.
        adjustment_type(str, optional): Specifies how the scaling adjustment is interpreted (for example, an absolute number or a percentage). The valid values are ChangeInCapacity, ExactCapacity, and PercentChangeInCapacity. Required if the policy type is StepScaling or SimpleScaling. For more information, see Scaling adjustment types in the Amazon EC2 Auto Scaling User Guide. Defaults to None.
        min_adjustment_step(int, optional): Available for backward compatibility. Use MinAdjustmentMagnitude instead. Defaults to None.
        min_adjustment_magnitude(int, optional): The minimum value to scale by when the adjustment type is PercentChangeInCapacity. For example, suppose that you create a step scaling policy to scale out an Auto Scaling group by 25 percent and you specify a MinAdjustmentMagnitude of 2. If the group has 4 instances and the scaling policy is performed, 25 percent of 4 is 1. However, because you specified a MinAdjustmentMagnitude of 2, Amazon EC2 Auto Scaling scales out the group by 2 instances. Valid only if the policy type is StepScaling or SimpleScaling. For more information, see Scaling adjustment types in the Amazon EC2 Auto Scaling User Guide.  Some Auto Scaling groups use instance weights. In this case, set the MinAdjustmentMagnitude to a value that is at least as large as your largest instance weight. . Defaults to None.
        scaling_adjustment(int, optional): The amount by which to scale, based on the specified adjustment type. A positive value adds to the current capacity while a negative number removes from the current capacity. For exact capacity, you must specify a positive value. Required if the policy type is SimpleScaling. (Not used with any other policy type.) . Defaults to None.
        cooldown(int, optional): The duration of the policy's cooldown period, in seconds. When a cooldown period is specified here, it overrides the default cooldown period defined for the Auto Scaling group. Valid only if the policy type is SimpleScaling. For more information, see Scaling cooldowns for Amazon EC2 Auto Scaling in the Amazon EC2 Auto Scaling User Guide. Defaults to None.
        metric_aggregation_type(str, optional): The aggregation type for the CloudWatch metrics. The valid values are Minimum, Maximum, and Average. If the aggregation type is null, the value is treated as Average. Valid only if the policy type is StepScaling. Defaults to None.
        step_adjustments(List, optional): A set of adjustments that enable you to scale based on the size of the alarm breach. Required if the policy type is StepScaling. (Not used with any other policy type.) . Defaults to None.
        estimated_instance_warmup(int, optional): The estimated time, in seconds, until a newly launched instance can contribute to the CloudWatch metrics. If not provided, the default is to use the value from the default cooldown period for the Auto Scaling group. Valid only if the policy type is TargetTrackingScaling or StepScaling. Defaults to None.
        target_tracking_configuration(Dict, optional): A target tracking scaling policy. Provides support for predefined or customized metrics. The following predefined metrics are available:    ASGAverageCPUUtilization     ASGAverageNetworkIn     ASGAverageNetworkOut     ALBRequestCountPerTarget    If you specify ALBRequestCountPerTarget for the metric, you must specify the ResourceLabel parameter with the PredefinedMetricSpecification. For more information, see TargetTrackingConfiguration in the Amazon EC2 Auto Scaling API Reference. Required if the policy type is TargetTrackingScaling. Defaults to None.
        enabled(bool, optional): Indicates whether the scaling policy is enabled or disabled. The default is enabled. For more information, see Disabling a scaling policy for an Auto Scaling group in the Amazon EC2 Auto Scaling User Guide. Defaults to None.
        predictive_scaling_configuration(Dict, optional): A predictive scaling policy. Provides support for only predefined metrics. Predictive scaling works with CPU utilization, network in/out, and the Application Load Balancer request count. For more information, see PredictiveScalingConfiguration in the Amazon EC2 Auto Scaling API Reference. Required if the policy type is PredictiveScaling. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.scaling.policy.put(
                ctx, auto_scaling_group_name=value, policy_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.scaling.policy.put auto_scaling_group_name=value, policy_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="put_scaling_policy",
        op_kwargs={
            "AutoScalingGroupName": auto_scaling_group_name,
            "PolicyName": policy_name,
            "PolicyType": policy_type,
            "AdjustmentType": adjustment_type,
            "MinAdjustmentStep": min_adjustment_step,
            "MinAdjustmentMagnitude": min_adjustment_magnitude,
            "ScalingAdjustment": scaling_adjustment,
            "Cooldown": cooldown,
            "MetricAggregationType": metric_aggregation_type,
            "StepAdjustments": step_adjustments,
            "EstimatedInstanceWarmup": estimated_instance_warmup,
            "TargetTrackingConfiguration": target_tracking_configuration,
            "Enabled": enabled,
            "PredictiveScalingConfiguration": predictive_scaling_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, datastore_id: str, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Displays the properties of a FHIR import job, including the ID, ARN, name, and the status of the job.

    Args:
        datastore_id(str): The AWS-generated ID of the Data Store.
        job_id(str): The AWS-generated job ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.healthlake.fhir.import_job.describe(
                ctx, datastore_id=value, job_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.healthlake.fhir.import_job.describe datastore_id=value, job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="healthlake",
        operation="describe_fhir_import_job",
        op_kwargs={"DatastoreId": datastore_id, "JobId": job_id},
    )


async def list_all(
    hub,
    ctx,
    datastore_id: str,
    next_token: str = None,
    max_results: int = None,
    job_name: str = None,
    job_status: str = None,
    submitted_before: str = None,
    submitted_after: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Lists all FHIR import jobs associated with an account and their statuses.

    Args:
        datastore_id(str):  This parameter limits the response to the import job with the specified Data Store ID. .
        next_token(str, optional):  A pagination token used to identify the next page of results to return for a ListFHIRImportJobs query. . Defaults to None.
        max_results(int, optional):  This parameter limits the number of results returned for a ListFHIRImportJobs to a maximum quantity specified by the user. . Defaults to None.
        job_name(str, optional):  This parameter limits the response to the import job with the specified job name. . Defaults to None.
        job_status(str, optional):  This parameter limits the response to the import job with the specified job status. . Defaults to None.
        submitted_before(str, optional):  This parameter limits the response to FHIR import jobs submitted before a user specified date. . Defaults to None.
        submitted_after(str, optional):  This parameter limits the response to FHIR import jobs submitted after a user specified date. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.healthlake.fhir.import_job.list_all(ctx, datastore_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.healthlake.fhir.import_job.list_all datastore_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="healthlake",
        operation="list_fhir_import_jobs",
        op_kwargs={
            "DatastoreId": datastore_id,
            "NextToken": next_token,
            "MaxResults": max_results,
            "JobName": job_name,
            "JobStatus": job_status,
            "SubmittedBefore": submitted_before,
            "SubmittedAfter": submitted_after,
        },
    )


async def start(
    hub,
    ctx,
    input_data_config: Dict,
    job_output_data_config: Dict,
    datastore_id: str,
    data_access_role_arn: str,
    client_token: str,
    job_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Begins a FHIR Import job.

    Args:
        job_name(str, optional): The name of the FHIR Import job in the StartFHIRImport job request. Defaults to None.
        input_data_config(Dict): The input properties of the FHIR Import job in the StartFHIRImport job request.
        job_output_data_config(Dict): The output data configuration that was supplied when the export job was created.
        datastore_id(str): The AWS-generated Data Store ID.
        data_access_role_arn(str): The Amazon Resource Name (ARN) that gives Amazon HealthLake access permission.
        client_token(str): Optional user provided token used for ensuring idempotency.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.healthlake.fhir.import_job.start(
                ctx,
                input_data_config=value,
                job_output_data_config=value,
                datastore_id=value,
                data_access_role_arn=value,
                client_token=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.healthlake.fhir.import_job.start input_data_config=value, job_output_data_config=value, datastore_id=value, data_access_role_arn=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="healthlake",
        operation="start_fhir_import_job",
        op_kwargs={
            "JobName": job_name,
            "InputDataConfig": input_data_config,
            "JobOutputDataConfig": job_output_data_config,
            "DatastoreId": datastore_id,
            "DataAccessRoleArn": data_access_role_arn,
            "ClientToken": client_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    source: Dict,
    artifact_type: str,
    artifact_name: str = None,
    properties: Dict = None,
    metadata_properties: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an artifact. An artifact is a lineage tracking entity that represents a URI addressable object or data. Some examples are the S3 URI of a dataset and the ECR registry path of an image. For more information, see Amazon SageMaker ML Lineage Tracking.   CreateArtifact can only be invoked from within an SageMaker managed environment. This includes SageMaker training jobs, processing jobs, transform jobs, and SageMaker notebooks. A call to CreateArtifact from outside one of these environments results in an error.

    Args:
        artifact_name(str, optional): The name of the artifact. Must be unique to your account in an Amazon Web Services Region. Defaults to None.
        source(Dict): The ID, ID type, and URI of the source.
        artifact_type(str): The artifact type.
        properties(Dict, optional): A list of properties to add to the artifact. Defaults to None.
        metadata_properties(Dict, optional): Metadata properties of the tracking entity, trial, or trial component. Defaults to None.
        tags(List, optional): A list of tags to apply to the artifact. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.artifact.create(
                ctx, source=value, artifact_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.artifact.create source=value, artifact_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_artifact",
        op_kwargs={
            "ArtifactName": artifact_name,
            "Source": source,
            "ArtifactType": artifact_type,
            "Properties": properties,
            "MetadataProperties": metadata_properties,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, artifact_arn: str = None, source: Dict = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an artifact. Either ArtifactArn or Source must be specified.

    Args:
        artifact_arn(str, optional): The Amazon Resource Name (ARN) of the artifact to delete. Defaults to None.
        source(Dict, optional): The URI of the source. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.artifact.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.artifact.delete
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_artifact",
        op_kwargs={"ArtifactArn": artifact_arn, "Source": source},
    )


async def describe(hub, ctx, artifact_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes an artifact.

    Args:
        artifact_arn(str): The Amazon Resource Name (ARN) of the artifact to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.artifact.describe(ctx, artifact_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.artifact.describe artifact_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_artifact",
        op_kwargs={"ArtifactArn": artifact_arn},
    )


async def list_all(
    hub,
    ctx,
    source_uri: str = None,
    artifact_type: str = None,
    created_after: str = None,
    created_before: str = None,
    sort_by: str = None,
    sort_order: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the artifacts in your account and their properties.

    Args:
        source_uri(str, optional): A filter that returns only artifacts with the specified source URI. Defaults to None.
        artifact_type(str, optional): A filter that returns only artifacts of the specified type. Defaults to None.
        created_after(str, optional): A filter that returns only artifacts created on or after the specified time. Defaults to None.
        created_before(str, optional): A filter that returns only artifacts created on or before the specified time. Defaults to None.
        sort_by(str, optional): The property used to sort results. The default value is CreationTime. Defaults to None.
        sort_order(str, optional): The sort order. The default value is Descending. Defaults to None.
        next_token(str, optional): If the previous call to ListArtifacts didn't return the full set of artifacts, the call returns a token for getting the next set of artifacts. Defaults to None.
        max_results(int, optional): The maximum number of artifacts to return in the response. The default value is 10. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.artifact.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.artifact.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_artifacts",
        op_kwargs={
            "SourceUri": source_uri,
            "ArtifactType": artifact_type,
            "CreatedAfter": created_after,
            "CreatedBefore": created_before,
            "SortBy": sort_by,
            "SortOrder": sort_order,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    artifact_arn: str,
    artifact_name: str = None,
    properties: Dict = None,
    properties_to_remove: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an artifact.

    Args:
        artifact_arn(str): The Amazon Resource Name (ARN) of the artifact to update.
        artifact_name(str, optional): The new name for the artifact. Defaults to None.
        properties(Dict, optional): The new list of properties. Overwrites the current property list. Defaults to None.
        properties_to_remove(List, optional): A list of properties to remove. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.artifact.update(ctx, artifact_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.artifact.update artifact_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="update_artifact",
        op_kwargs={
            "ArtifactArn": artifact_arn,
            "ArtifactName": artifact_name,
            "Properties": properties,
            "PropertiesToRemove": properties_to_remove,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def attach(hub, ctx, policy_id: str, target_id: str) -> None:
    r"""
    **Autogenerated function**

    Attaches a policy to a root, an organizational unit (OU), or an individual account. How the policy affects accounts depends on the type of policy. Refer to the AWS Organizations User Guide for information about each policy type:    AISERVICES_OPT_OUT_POLICY     BACKUP_POLICY     SERVICE_CONTROL_POLICY     TAG_POLICY    This operation can be called only from the organization's management account.

    Args:
        policy_id(str): The unique identifier (ID) of the policy that you want to attach to the target. You can get the ID for the policy by calling the ListPolicies operation. The regex pattern for a policy ID string requires "p-" followed by from 8 to 128 lowercase or uppercase letters, digits, or the underscore character (_).
        target_id(str): The unique identifier (ID) of the root, OU, or account that you want to attach the policy to. You can get the ID by calling the ListRoots, ListOrganizationalUnitsForParent, or ListAccounts operations. The regex pattern for a target ID string requires one of the following:    Root - A string that begins with "r-" followed by from 4 to 32 lowercase letters or digits.    Account - A string that consists of exactly 12 digits.    Organizational unit (OU) - A string that begins with "ou-" followed by from 4 to 32 lowercase letters or digits (the ID of the root that the OU is in). This string is followed by a second "-" dash and from 8 to 32 additional lowercase letters or digits.  .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.policy.init.attach(
                ctx, policy_id=value, target_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.policy.init.attach policy_id=value, target_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="attach_policy",
        op_kwargs={"PolicyId": policy_id, "TargetId": target_id},
    )


async def create(
    hub, ctx, content: str, description: str, name: str, type_: str, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a policy of a specified type that you can attach to a root, an organizational unit (OU), or an individual AWS account. For more information about policies and their use, see Managing Organization Policies. If the request includes tags, then the requester must have the organizations:TagResource permission. This operation can be called only from the organization's management account.

    Args:
        content(str): The policy text content to add to the new policy. The text that you supply must adhere to the rules of the policy type you specify in the Type parameter.
        description(str): An optional description to assign to the policy.
        name(str): The friendly name to assign to the policy. The regex pattern that is used to validate this parameter is a string of any of the characters in the ASCII character range.
        type_(str): The type of policy to create. You can specify one of the following values:    AISERVICES_OPT_OUT_POLICY     BACKUP_POLICY     SERVICE_CONTROL_POLICY     TAG_POLICY   .
        tags(List, optional): A list of tags that you want to attach to the newly created policy. For each tag in the list, you must specify both a tag key and a value. You can set the value to an empty string, but you can't set it to null. For more information about tagging, see Tagging AWS Organizations resources in the AWS Organizations User Guide.  If any one of the tags is invalid or if you exceed the allowed number of tags for a policy, then the entire request fails and the policy is not created. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.policy.init.create(
                ctx, content=value, description=value, name=value, type_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.policy.init.create content=value, description=value, name=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="create_policy",
        op_kwargs={
            "Content": content,
            "Description": description,
            "Name": name,
            "Type": type_,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, policy_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified policy from your organization. Before you perform this operation, you must first detach the policy from all organizational units (OUs), roots, and accounts. This operation can be called only from the organization's management account.

    Args:
        policy_id(str): The unique identifier (ID) of the policy that you want to delete. You can get the ID from the ListPolicies or ListPoliciesForTarget operations. The regex pattern for a policy ID string requires "p-" followed by from 8 to 128 lowercase or uppercase letters, digits, or the underscore character (_).
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.policy.init.delete(ctx, policy_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.policy.init.delete policy_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="delete_policy",
        op_kwargs={"PolicyId": policy_id},
    )


async def describe(hub, ctx, policy_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about a policy. This operation can be called only from the organization's management account or by a member account that is a delegated administrator for an AWS service.

    Args:
        policy_id(str): The unique identifier (ID) of the policy that you want details about. You can get the ID from the ListPolicies or ListPoliciesForTarget operations. The regex pattern for a policy ID string requires "p-" followed by from 8 to 128 lowercase or uppercase letters, digits, or the underscore character (_).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.policy.init.describe(ctx, policy_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.policy.init.describe policy_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="describe_policy",
        op_kwargs={"PolicyId": policy_id},
    )


async def detach(hub, ctx, policy_id: str, target_id: str) -> None:
    r"""
    **Autogenerated function**

    Detaches a policy from a target root, organizational unit (OU), or account.  If the policy being detached is a service control policy (SCP), the changes to permissions for AWS Identity and Access Management (IAM) users and roles in affected accounts are immediate.  Every root, OU, and account must have at least one SCP attached. If you want to replace the default FullAWSAccess policy with an SCP that limits the permissions that can be delegated, you must attach the replacement SCP before you can remove the default SCP. This is the authorization strategy of an "allow list". If you instead attach a second SCP and leave the FullAWSAccess SCP still attached, and specify "Effect": "Deny" in the second SCP to override the "Effect": "Allow" in the FullAWSAccess policy (or any other attached SCP), you're using the authorization strategy of a "deny list". This operation can be called only from the organization's management account.

    Args:
        policy_id(str): The unique identifier (ID) of the policy you want to detach. You can get the ID from the ListPolicies or ListPoliciesForTarget operations. The regex pattern for a policy ID string requires "p-" followed by from 8 to 128 lowercase or uppercase letters, digits, or the underscore character (_).
        target_id(str): The unique identifier (ID) of the root, OU, or account that you want to detach the policy from. You can get the ID from the ListRoots, ListOrganizationalUnitsForParent, or ListAccounts operations. The regex pattern for a target ID string requires one of the following:    Root - A string that begins with "r-" followed by from 4 to 32 lowercase letters or digits.    Account - A string that consists of exactly 12 digits.    Organizational unit (OU) - A string that begins with "ou-" followed by from 4 to 32 lowercase letters or digits (the ID of the root that the OU is in). This string is followed by a second "-" dash and from 8 to 32 additional lowercase letters or digits.  .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.policy.init.detach(
                ctx, policy_id=value, target_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.policy.init.detach policy_id=value, target_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="detach_policy",
        op_kwargs={"PolicyId": policy_id, "TargetId": target_id},
    )


async def list_all(
    hub, ctx, filter_: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the list of all policies in an organization of a specified type.  Always check the NextToken response parameter for a null value when calling a List* operation. These operations can occasionally return an empty set of results even when there are more results available. The NextToken response parameter value is null only when there are no more results to display.  This operation can be called only from the organization's management account or by a member account that is a delegated administrator for an AWS service.

    Args:
        filter_(str): Specifies the type of policy that you want to include in the response. You must specify one of the following values:    AISERVICES_OPT_OUT_POLICY     BACKUP_POLICY     SERVICE_CONTROL_POLICY     TAG_POLICY   .
        next_token(str, optional): The parameter for receiving additional results if you receive a NextToken response in a previous request. A NextToken response indicates that more output is available. Set this parameter to the value of the previous call's NextToken response to indicate where the output should continue from. Defaults to None.
        max_results(int, optional): The total number of results that you want included on each page of the response. If you do not include this parameter, it defaults to a value that is specific to the operation. If additional items exist beyond the maximum you specify, the NextToken response element is present and has a value (is not null). Include that value as the NextToken request parameter in the next call to the operation to get the next part of the results. Note that Organizations might return fewer results than the maximum even when there are more results available. You should check NextToken after every operation to ensure that you receive all of the results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.policy.init.list_all(ctx, filter_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.policy.init.list_all filter_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="list_policies",
        op_kwargs={
            "Filter": filter_,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    policy_id: str,
    name: str = None,
    description: str = None,
    content: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing policy with a new name, description, or content. If you don't supply any parameter, that value remains unchanged. You can't change a policy's type. This operation can be called only from the organization's management account.

    Args:
        policy_id(str): The unique identifier (ID) of the policy that you want to update. The regex pattern for a policy ID string requires "p-" followed by from 8 to 128 lowercase or uppercase letters, digits, or the underscore character (_).
        name(str, optional): If provided, the new name for the policy. The regex pattern that is used to validate this parameter is a string of any of the characters in the ASCII character range. Defaults to None.
        description(str, optional): If provided, the new description for the policy. Defaults to None.
        content(str, optional): If provided, the new content for the policy. The text must be correctly formatted JSON that complies with the syntax for the policy's type. For more information, see Service Control Policy Syntax in the AWS Organizations User Guide. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.organization.policy.init.update(ctx, policy_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.organization.policy.init.update policy_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="organizations",
        operation="update_policy",
        op_kwargs={
            "PolicyId": policy_id,
            "Name": name,
            "Description": description,
            "Content": content,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    spec: str,
    template_major_version: str,
    template_name: str,
    description: str = None,
    environment_account_connection_id: str = None,
    proton_service_role_arn: str = None,
    tags: List = None,
    template_minor_version: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deploy a new environment. An AWS Proton environment is created from an environment template that defines infrastructure and resources that can be shared across services. For more information, see the Environments in the AWS Proton Administrator Guide.

    Args:
        description(str, optional): A description of the environment that's being created and deployed. Defaults to None.
        environment_account_connection_id(str, optional): The ID of the environment account connection that you provide if you're provisioning your environment infrastructure resources to an environment account. You must include either the environmentAccountConnectionId or protonServiceRoleArn parameter and value. For more information, see Environment account connections in the AWS Proton Administrator guide. Defaults to None.
        name(str): The name of the environment.
        proton_service_role_arn(str, optional): The Amazon Resource Name (ARN) of the AWS Proton service role that allows AWS Proton to make calls to other services on your behalf. You must include either the environmentAccountConnectionId or protonServiceRoleArn parameter and value. Defaults to None.
        spec(str): A link to a YAML formatted spec file that provides inputs as defined in the environment template bundle schema file. For more information, see Environments in the AWS Proton Administrator Guide.
        tags(List, optional): Create tags for your environment. For more information, see AWS Proton resources and tagging in the AWS Proton Administrator Guide or AWS Proton User Guide. Defaults to None.
        template_major_version(str): The ID of the major version of the environment template.
        template_minor_version(str, optional): The ID of the minor version of the environment template. Defaults to None.
        template_name(str): The name of the environment template. For more information, see Environment Templates in the AWS Proton Administrator Guide.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.environment.init.create(
                ctx, name=value, spec=value, template_major_version=value, template_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.environment.init.create name=value, spec=value, template_major_version=value, template_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="create_environment",
        op_kwargs={
            "description": description,
            "environmentAccountConnectionId": environment_account_connection_id,
            "name": name,
            "protonServiceRoleArn": proton_service_role_arn,
            "spec": spec,
            "tags": tags,
            "templateMajorVersion": template_major_version,
            "templateMinorVersion": template_minor_version,
            "templateName": template_name,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Delete an environment.

    Args:
        name(str): The name of the environment to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.environment.init.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.environment.init.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="delete_environment",
        op_kwargs={"name": name},
    )


async def get(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Get detail data for an environment.

    Args:
        name(str): The name of the environment that you want to get the detail data for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.environment.init.get(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.environment.init.get name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="get_environment",
        op_kwargs={"name": name},
    )


async def list_all(
    hub,
    ctx,
    environment_templates: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    List environments with detail data summaries.

    Args:
        environment_templates(List, optional): An array of the versions of the environment template. Defaults to None.
        max_results(int, optional): The maximum number of environments to list. Defaults to None.
        next_token(str, optional): A token to indicate the location of the next environment in the array of environments, after the list of environments that was previously requested. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.environment.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.environment.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="list_environments",
        op_kwargs={
            "environmentTemplates": environment_templates,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    deployment_type: str,
    name: str,
    description: str = None,
    environment_account_connection_id: str = None,
    proton_service_role_arn: str = None,
    spec: str = None,
    template_major_version: str = None,
    template_minor_version: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Update an environment. If the environment is associated with an environment account connection, don't update or include the protonServiceRoleArn parameter to update or connect to an environment account connection.  You can only update to a new environment account connection if it was created in the same environment account that the current environment account connection was created in and is associated with the current environment. If the environment isn't associated with an environment account connection, don't update or include the environmentAccountConnectionId parameter to update or connect to an environment account connection. You can update either the environmentAccountConnectionId or protonServiceRoleArn parameter and value. You can’t update both. There are four modes for updating an environment as described in the following. The deploymentType field defines the mode.     NONE  In this mode, a deployment doesn't occur. Only the requested metadata parameters are updated.     CURRENT_VERSION  In this mode, the environment is deployed and updated with the new spec that you provide. Only requested parameters are updated. Don’t include minor or major version parameters when you use this deployment-type.     MINOR_VERSION  In this mode, the environment is deployed and updated with the published, recommended (latest) minor version of the current major version in use, by default. You can also specify a different minor version of the current major version in use.     MAJOR_VERSION  In this mode, the environment is deployed and updated with the published, recommended (latest) major and minor version of the current template, by default. You can also specify a different major version that's higher than the major version in use and a minor version (optional).

    Args:
        deployment_type(str): There are four modes for updating an environment as described in the following. The deploymentType field defines the mode.     NONE  In this mode, a deployment doesn't occur. Only the requested metadata parameters are updated.     CURRENT_VERSION  In this mode, the environment is deployed and updated with the new spec that you provide. Only requested parameters are updated. Don’t include minor or major version parameters when you use this deployment-type.     MINOR_VERSION  In this mode, the environment is deployed and updated with the published, recommended (latest) minor version of the current major version in use, by default. You can also specify a different minor version of the current major version in use.     MAJOR_VERSION  In this mode, the environment is deployed and updated with the published, recommended (latest) major and minor version of the current template, by default. You can also specify a different major version that is higher than the major version in use and a minor version (optional).  .
        description(str, optional): A description of the environment update. Defaults to None.
        environment_account_connection_id(str, optional): The ID of the environment account connection. You can only update to a new environment account connection if it was created in the same environment account that the current environment account connection was created in and is associated with the current environment. Defaults to None.
        name(str): The name of the environment to update.
        proton_service_role_arn(str, optional): The Amazon Resource Name (ARN) of the AWS Proton service role that allows AWS Proton to make API calls to other services your behalf. Defaults to None.
        spec(str, optional): The formatted specification that defines the update. Defaults to None.
        template_major_version(str, optional): The ID of the major version of the environment to update. Defaults to None.
        template_minor_version(str, optional): The ID of the minor version of the environment to update. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.environment.init.update(
                ctx, deployment_type=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.environment.init.update deployment_type=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="update_environment",
        op_kwargs={
            "deploymentType": deployment_type,
            "description": description,
            "environmentAccountConnectionId": environment_account_connection_id,
            "name": name,
            "protonServiceRoleArn": proton_service_role_arn,
            "spec": spec,
            "templateMajorVersion": template_major_version,
            "templateMinorVersion": template_minor_version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(hub, ctx, account_id: str, user_id_list: List) -> Dict:
    r"""
    **Autogenerated function**

    Suspends up to 50 users from a Team or EnterpriseLWA Amazon Chime account. For more information about different account types, see Managing Your Amazon Chime Accounts in the Amazon Chime Administration Guide. Users suspended from a Team account are disassociated from the account,but they can continue to use Amazon Chime as free users. To remove the suspension from suspended Team account users, invite them to the Team account again. You can use the InviteUsers action to do so. Users suspended from an EnterpriseLWA account are immediately signed out of Amazon Chime and can no longer sign in. To remove the suspension from suspended EnterpriseLWA account users, use the BatchUnsuspendUser action.  To sign out users without suspending them, use the LogoutUser action.

    Args:
        account_id(str): The Amazon Chime account ID.
        user_id_list(List): The request containing the user IDs to suspend.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.suspend_user.batch(
                ctx, account_id=value, user_id_list=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.suspend_user.batch account_id=value, user_id_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="batch_suspend_user",
        op_kwargs={"AccountId": account_id, "UserIdList": user_id_list},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"set_": "set"}


async def set_(
    hub, ctx, load_balancer_name: str, load_balancer_port: int, policy_names: List
) -> Dict:
    r"""
    **Autogenerated function**

    Replaces the current set of policies for the specified load balancer port with the specified set of policies. To enable back-end server authentication, use SetLoadBalancerPoliciesForBackendServer. For more information about setting policies, see Update the SSL Negotiation Configuration, Duration-Based Session Stickiness, and Application-Controlled Session Stickiness in the Classic Load Balancers Guide.

    Args:
        load_balancer_name(str): The name of the load balancer.
        load_balancer_port(int): The external port of the load balancer.
        policy_names(List): The names of the policies. This list must include all policies to be enabled. If you omit a policy that is currently enabled, it is disabled. If the list is empty, all current policies are disabled.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elb.load_balancer.policy.of_listener.set(
                ctx, load_balancer_name=value, load_balancer_port=value, policy_names=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elb.load_balancer.policy.of_listener.set load_balancer_name=value, load_balancer_port=value, policy_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elb",
        operation="set_load_balancer_policies_of_listener",
        op_kwargs={
            "LoadBalancerName": load_balancer_name,
            "LoadBalancerPort": load_balancer_port,
            "PolicyNames": policy_names,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    stream_name: str = None,
    next_token: str = None,
    exclusive_start_shard_id: str = None,
    max_results: int = None,
    stream_creation_timestamp: str = None,
    shard_filter: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the shards in a stream and provides information about each shard. This operation has a limit of 100 transactions per second per data stream.  This API is a new operation that is used by the Amazon Kinesis Client Library (KCL). If you have a fine-grained IAM policy that only allows specific operations, you must update your policy to allow calls to this API. For more information, see Controlling Access to Amazon Kinesis Data Streams Resources Using IAM.

    Args:
        stream_name(str, optional): The name of the data stream whose shards you want to list.  You cannot specify this parameter if you specify the NextToken parameter. Defaults to None.
        next_token(str, optional): When the number of shards in the data stream is greater than the default value for the MaxResults parameter, or if you explicitly specify a value for MaxResults that is less than the number of shards in the data stream, the response includes a pagination token named NextToken. You can specify this NextToken value in a subsequent call to ListShards to list the next set of shards. Don't specify StreamName or StreamCreationTimestamp if you specify NextToken because the latter unambiguously identifies the stream. You can optionally specify a value for the MaxResults parameter when you specify NextToken. If you specify a MaxResults value that is less than the number of shards that the operation returns if you don't specify MaxResults, the response will contain a new NextToken value. You can use the new NextToken value in a subsequent call to the ListShards operation.  Tokens expire after 300 seconds. When you obtain a value for NextToken in the response to a call to ListShards, you have 300 seconds to use that value. If you specify an expired token in a call to ListShards, you get ExpiredNextTokenException. . Defaults to None.
        exclusive_start_shard_id(str, optional): Specify this parameter to indicate that you want to list the shards starting with the shard whose ID immediately follows ExclusiveStartShardId. If you don't specify this parameter, the default behavior is for ListShards to list the shards starting with the first one in the stream. You cannot specify this parameter if you specify NextToken. Defaults to None.
        max_results(int, optional): The maximum number of shards to return in a single call to ListShards. The minimum value you can specify for this parameter is 1, and the maximum is 10,000, which is also the default. When the number of shards to be listed is greater than the value of MaxResults, the response contains a NextToken value that you can use in a subsequent call to ListShards to list the next set of shards. Defaults to None.
        stream_creation_timestamp(str, optional): Specify this input parameter to distinguish data streams that have the same name. For example, if you create a data stream and then delete it, and you later create another data stream with the same name, you can use this input parameter to specify which of the two streams you want to list the shards for. You cannot specify this parameter if you specify the NextToken parameter. Defaults to None.
        shard_filter(Dict, optional): . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesis.shard.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesis.shard.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesis",
        operation="list_shards",
        op_kwargs={
            "StreamName": stream_name,
            "NextToken": next_token,
            "ExclusiveStartShardId": exclusive_start_shard_id,
            "MaxResults": max_results,
            "StreamCreationTimestamp": stream_creation_timestamp,
            "ShardFilter": shard_filter,
        },
    )


async def merge(
    hub, ctx, stream_name: str, shard_to_merge: str, adjacent_shard_to_merge: str
) -> None:
    r"""
    **Autogenerated function**

    Merges two adjacent shards in a Kinesis data stream and combines them into a single shard to reduce the stream's capacity to ingest and transport data. Two shards are considered adjacent if the union of the hash key ranges for the two shards form a contiguous set with no gaps. For example, if you have two shards, one with a hash key range of 276...381 and the other with a hash key range of 382...454, then you could merge these two shards into a single shard that would have a hash key range of 276...454. After the merge, the single child shard receives data for all hash key values covered by the two parent shards.  MergeShards is called when there is a need to reduce the overall capacity of a stream because of excess capacity that is not being used. You must specify the shard to be merged and the adjacent shard for a stream. For more information about merging shards, see Merge Two Shards in the Amazon Kinesis Data Streams Developer Guide. If the stream is in the ACTIVE state, you can call MergeShards. If a stream is in the CREATING, UPDATING, or DELETING state, MergeShards returns a ResourceInUseException. If the specified stream does not exist, MergeShards returns a ResourceNotFoundException.  You can use DescribeStream to check the state of the stream, which is returned in StreamStatus.  MergeShards is an asynchronous operation. Upon receiving a MergeShards request, Amazon Kinesis Data Streams immediately returns a response and sets the StreamStatus to UPDATING. After the operation is completed, Kinesis Data Streams sets the StreamStatus to ACTIVE. Read and write operations continue to work while the stream is in the UPDATING state.  You use DescribeStream to determine the shard IDs that are specified in the MergeShards request.  If you try to operate on too many streams in parallel using CreateStream, DeleteStream, MergeShards, or SplitShard, you receive a LimitExceededException.   MergeShards has a limit of five transactions per second per account.

    Args:
        stream_name(str): The name of the stream for the merge.
        shard_to_merge(str): The shard ID of the shard to combine with the adjacent shard for the merge.
        adjacent_shard_to_merge(str): The shard ID of the adjacent shard for the merge.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesis.shard.init.merge(
                ctx, stream_name=value, shard_to_merge=value, adjacent_shard_to_merge=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesis.shard.init.merge stream_name=value, shard_to_merge=value, adjacent_shard_to_merge=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesis",
        operation="merge_shards",
        op_kwargs={
            "StreamName": stream_name,
            "ShardToMerge": shard_to_merge,
            "AdjacentShardToMerge": adjacent_shard_to_merge,
        },
    )


async def split(
    hub, ctx, stream_name: str, shard_to_split: str, new_starting_hash_key: str
) -> None:
    r"""
    **Autogenerated function**

    Splits a shard into two new shards in the Kinesis data stream, to increase the stream's capacity to ingest and transport data. SplitShard is called when there is a need to increase the overall capacity of a stream because of an expected increase in the volume of data records being ingested.  You can also use SplitShard when a shard appears to be approaching its maximum utilization; for example, the producers sending data into the specific shard are suddenly sending more than previously anticipated. You can also call SplitShard to increase stream capacity, so that more Kinesis Data Streams applications can simultaneously read data from the stream for real-time processing.  You must specify the shard to be split and the new hash key, which is the position in the shard where the shard gets split in two. In many cases, the new hash key might be the average of the beginning and ending hash key, but it can be any hash key value in the range being mapped into the shard. For more information, see Split a Shard in the Amazon Kinesis Data Streams Developer Guide. You can use DescribeStream to determine the shard ID and hash key values for the ShardToSplit and NewStartingHashKey parameters that are specified in the SplitShard request.  SplitShard is an asynchronous operation. Upon receiving a SplitShard request, Kinesis Data Streams immediately returns a response and sets the stream status to UPDATING. After the operation is completed, Kinesis Data Streams sets the stream status to ACTIVE. Read and write operations continue to work while the stream is in the UPDATING state.  You can use DescribeStream to check the status of the stream, which is returned in StreamStatus. If the stream is in the ACTIVE state, you can call SplitShard. If a stream is in CREATING or UPDATING or DELETING states, DescribeStream returns a ResourceInUseException. If the specified stream does not exist, DescribeStream returns a ResourceNotFoundException. If you try to create more shards than are authorized for your account, you receive a LimitExceededException.  For the default shard limit for an AWS account, see Kinesis Data Streams Limits in the Amazon Kinesis Data Streams Developer Guide. To increase this limit, contact AWS Support. If you try to operate on too many streams simultaneously using CreateStream, DeleteStream, MergeShards, and/or SplitShard, you receive a LimitExceededException.   SplitShard has a limit of five transactions per second per account.

    Args:
        stream_name(str): The name of the stream for the shard split.
        shard_to_split(str): The shard ID of the shard to split.
        new_starting_hash_key(str): A hash key value for the starting hash key of one of the child shards created by the split. The hash key range for a given shard constitutes a set of ordered contiguous positive integers. The value for NewStartingHashKey must be in the range of hash keys being mapped into the shard. The NewStartingHashKey hash key value and all higher hash key values in hash key range are distributed to one of the child shards. All the lower hash key values in the range are distributed to the other child shard.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesis.shard.init.split(
                ctx, stream_name=value, shard_to_split=value, new_starting_hash_key=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesis.shard.init.split stream_name=value, shard_to_split=value, new_starting_hash_key=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesis",
        operation="split_shard",
        op_kwargs={
            "StreamName": stream_name,
            "ShardToSplit": shard_to_split,
            "NewStartingHashKey": new_starting_hash_key,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def replace(
    hub, ctx, association_id: str, route_table_id: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Changes the route table associated with a given subnet, internet gateway, or virtual private gateway in a VPC. After the operation completes, the subnet or gateway uses the routes in the new route table. For more information about route tables, see Route tables in the Amazon Virtual Private Cloud User Guide. You can also use this operation to change which table is the main route table in the VPC. Specify the main route table's association ID and the route table ID of the new main route table.

    Args:
        association_id(str): The association ID.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        route_table_id(str): The ID of the new route table to associate with the subnet.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.route.table.association.replace(
                ctx, association_id=value, route_table_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.route.table.association.replace association_id=value, route_table_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="replace_route_table_association",
        op_kwargs={
            "AssociationId": association_id,
            "DryRun": dry_run,
            "RouteTableId": route_table_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    sort_order: str = None,
    sort_by: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Gets a list of report groups that are shared with other AWS accounts or users.

    Args:
        sort_order(str, optional): The order in which to list shared report groups. Valid values include:    ASCENDING: List in ascending order.    DESCENDING: List in descending order.  . Defaults to None.
        sort_by(str, optional):  The criterion to be used to list report groups shared with the current AWS account or user. Valid values include:     ARN: List based on the ARN.     MODIFIED_TIME: List based on when information about the shared report group was last changed.   . Defaults to None.
        next_token(str, optional):  During a previous call, the maximum number of items that can be returned is the value specified in maxResults. If there more items in the list, then a unique string called a nextToken is returned. To get the next batch of items in the list, call this operation again, adding the next token to the call. To get all of the items in the list, keep calling this operation with each subsequent next token that is returned, until no more next tokens are returned. . Defaults to None.
        max_results(int, optional):  The maximum number of paginated shared report groups per response. Use nextToken to iterate pages in the list of returned ReportGroup objects. The default value is 100. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.shared.report_group.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.shared.report_group.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="list_shared_report_groups",
        op_kwargs={
            "sortOrder": sort_order,
            "sortBy": sort_by,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"continue_": "continue"}


async def continue_(
    hub, ctx, deployment_id: str = None, deployment_wait_type: str = None
) -> None:
    r"""
    **Autogenerated function**

    For a blue/green deployment, starts the process of rerouting traffic from instances in the original environment to instances in the replacement environment without waiting for a specified wait time to elapse. (Traffic rerouting, which is achieved by registering instances in the replacement environment with the load balancer, can start as soon as all instances have a status of Ready.)

    Args:
        deployment_id(str, optional):  The unique ID of a blue/green deployment for which you want to start rerouting traffic to the replacement environment. . Defaults to None.
        deployment_wait_type(str, optional):  The status of the deployment's waiting period. READY_WAIT indicates that the deployment is ready to start shifting traffic. TERMINATION_WAIT indicates that the traffic is shifted, but the original target is not terminated. . Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.deployment.init.continue(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.deployment.init.continue
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="continue_deployment",
        op_kwargs={
            "deploymentId": deployment_id,
            "deploymentWaitType": deployment_wait_type,
        },
    )


async def create(
    hub,
    ctx,
    application_name: str,
    deployment_group_name: str = None,
    revision: Dict = None,
    deployment_config_name: str = None,
    description: str = None,
    ignore_application_stop_failures: bool = None,
    target_instances: Dict = None,
    auto_rollback_configuration: Dict = None,
    update_outdated_instances_only: bool = None,
    file_exists_behavior: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deploys an application revision through the specified deployment group.

    Args:
        application_name(str): The name of an AWS CodeDeploy application associated with the IAM user or AWS account.
        deployment_group_name(str, optional): The name of the deployment group. Defaults to None.
        revision(Dict, optional):  The type and location of the revision to deploy. . Defaults to None.
        deployment_config_name(str, optional): The name of a deployment configuration associated with the IAM user or AWS account. If not specified, the value configured in the deployment group is used as the default. If the deployment group does not have a deployment configuration associated with it, CodeDeployDefault.OneAtATime is used by default. Defaults to None.
        description(str, optional): A comment about the deployment. Defaults to None.
        ignore_application_stop_failures(bool, optional):  If true, then if an ApplicationStop, BeforeBlockTraffic, or AfterBlockTraffic deployment lifecycle event to an instance fails, then the deployment continues to the next deployment lifecycle event. For example, if ApplicationStop fails, the deployment continues with DownloadBundle. If BeforeBlockTraffic fails, the deployment continues with BlockTraffic. If AfterBlockTraffic fails, the deployment continues with ApplicationStop.   If false or not specified, then if a lifecycle event fails during a deployment to an instance, that deployment fails. If deployment to that instance is part of an overall deployment and the number of healthy hosts is not less than the minimum number of healthy hosts, then a deployment to the next instance is attempted.   During a deployment, the AWS CodeDeploy agent runs the scripts specified for ApplicationStop, BeforeBlockTraffic, and AfterBlockTraffic in the AppSpec file from the previous successful deployment. (All other scripts are run from the AppSpec file in the current deployment.) If one of these scripts contains an error and does not run successfully, the deployment can fail.   If the cause of the failure is a script from the last successful deployment that will never run successfully, create a new deployment and use ignoreApplicationStopFailures to specify that the ApplicationStop, BeforeBlockTraffic, and AfterBlockTraffic failures should be ignored. . Defaults to None.
        target_instances(Dict, optional):  Information about the instances that belong to the replacement environment in a blue/green deployment. . Defaults to None.
        auto_rollback_configuration(Dict, optional): Configuration information for an automatic rollback that is added when a deployment is created. Defaults to None.
        update_outdated_instances_only(bool, optional):  Indicates whether to deploy to all instances or only to instances that are not running the latest application revision. . Defaults to None.
        file_exists_behavior(str, optional): Information about how AWS CodeDeploy handles files that already exist in a deployment target location but weren't part of the previous successful deployment. The fileExistsBehavior parameter takes any of the following values:   DISALLOW: The deployment fails. This is also the default behavior if no option is specified.   OVERWRITE: The version of the file from the application revision currently being deployed replaces the version already on the instance.   RETAIN: The version of the file already on the instance is kept and used as part of the new deployment.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.deployment.init.create(ctx, application_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.deployment.init.create application_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="create_deployment",
        op_kwargs={
            "applicationName": application_name,
            "deploymentGroupName": deployment_group_name,
            "revision": revision,
            "deploymentConfigName": deployment_config_name,
            "description": description,
            "ignoreApplicationStopFailures": ignore_application_stop_failures,
            "targetInstances": target_instances,
            "autoRollbackConfiguration": auto_rollback_configuration,
            "updateOutdatedInstancesOnly": update_outdated_instances_only,
            "fileExistsBehavior": file_exists_behavior,
        },
    )


async def get(hub, ctx, deployment_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a deployment.   The content property of the appSpecContent object in the returned revision is always null. Use GetApplicationRevision and the sha256 property of the returned appSpecContent object to get the content of the deployment’s AppSpec file.

    Args:
        deployment_id(str):  The unique ID of a deployment associated with the IAM user or AWS account. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.deployment.init.get(ctx, deployment_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.deployment.init.get deployment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="get_deployment",
        op_kwargs={"deploymentId": deployment_id},
    )


async def list_all(
    hub,
    ctx,
    application_name: str = None,
    deployment_group_name: str = None,
    external_id: str = None,
    include_only_statuses: List = None,
    create_time_range: Dict = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the deployments in a deployment group for an application registered with the IAM user or AWS account.

    Args:
        application_name(str, optional): The name of an AWS CodeDeploy application associated with the IAM user or AWS account.  If applicationName is specified, then deploymentGroupName must be specified. If it is not specified, then deploymentGroupName must not be specified.  . Defaults to None.
        deployment_group_name(str, optional): The name of a deployment group for the specified application.  If deploymentGroupName is specified, then applicationName must be specified. If it is not specified, then applicationName must not be specified.  . Defaults to None.
        external_id(str, optional): The unique ID of an external resource for returning deployments linked to the external resource. Defaults to None.
        include_only_statuses(List, optional): A subset of deployments to list by status:    Created: Include created deployments in the resulting list.    Queued: Include queued deployments in the resulting list.    In Progress: Include in-progress deployments in the resulting list.    Succeeded: Include successful deployments in the resulting list.    Failed: Include failed deployments in the resulting list.    Stopped: Include stopped deployments in the resulting list.  . Defaults to None.
        create_time_range(Dict, optional): A time range (start and end) for returning a subset of the list of deployments. Defaults to None.
        next_token(str, optional): An identifier returned from the previous list deployments call. It can be used to return the next set of deployments in the list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.deployment.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.deployment.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="list_deployments",
        op_kwargs={
            "applicationName": application_name,
            "deploymentGroupName": deployment_group_name,
            "externalId": external_id,
            "includeOnlyStatuses": include_only_statuses,
            "createTimeRange": create_time_range,
            "nextToken": next_token,
        },
    )


async def stop(
    hub, ctx, deployment_id: str, auto_rollback_enabled: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Attempts to stop an ongoing deployment.

    Args:
        deployment_id(str):  The unique ID of a deployment. .
        auto_rollback_enabled(bool, optional):  Indicates, when a deployment is stopped, whether instances that have been updated should be rolled back to the previous version of the application revision. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.deployment.init.stop(ctx, deployment_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.deployment.init.stop deployment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="stop_deployment",
        op_kwargs={
            "deploymentId": deployment_id,
            "autoRollbackEnabled": auto_rollback_enabled,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    database_name: str,
    table_input: Dict,
    catalog_id: str = None,
    partition_indexes: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new table definition in the Data Catalog.

    Args:
        catalog_id(str, optional): The ID of the Data Catalog in which to create the Table. If none is supplied, the Amazon Web Services account ID is used by default. Defaults to None.
        database_name(str): The catalog database in which to create the new table. For Hive compatibility, this name is entirely lowercase.
        table_input(Dict): The TableInput object that defines the metadata table to create in the catalog.
        partition_indexes(List, optional): A list of partition indexes, PartitionIndex structures, to create in the table. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.table.init.create(
                ctx, database_name=value, table_input=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.table.init.create database_name=value, table_input=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="create_table",
        op_kwargs={
            "CatalogId": catalog_id,
            "DatabaseName": database_name,
            "TableInput": table_input,
            "PartitionIndexes": partition_indexes,
        },
    )


async def delete(
    hub, ctx, database_name: str, name: str, catalog_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Removes a table definition from the Data Catalog.  After completing this operation, you no longer have access to the table versions and partitions that belong to the deleted table. Glue deletes these "orphaned" resources asynchronously in a timely manner, at the discretion of the service. To ensure the immediate deletion of all related resources, before calling DeleteTable, use DeleteTableVersion or BatchDeleteTableVersion, and DeletePartition or BatchDeletePartition, to delete any resources that belong to the table.

    Args:
        catalog_id(str, optional): The ID of the Data Catalog where the table resides. If none is provided, the Amazon Web Services account ID is used by default. Defaults to None.
        database_name(str): The name of the catalog database in which the table resides. For Hive compatibility, this name is entirely lowercase.
        name(str): The name of the table to be deleted. For Hive compatibility, this name is entirely lowercase.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.table.init.delete(ctx, database_name=value, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.table.init.delete database_name=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="delete_table",
        op_kwargs={
            "CatalogId": catalog_id,
            "DatabaseName": database_name,
            "Name": name,
        },
    )


async def get(hub, ctx, database_name: str, name: str, catalog_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the Table definition in a Data Catalog for a specified table.

    Args:
        catalog_id(str, optional): The ID of the Data Catalog where the table resides. If none is provided, the Amazon Web Services account ID is used by default. Defaults to None.
        database_name(str): The name of the database in the catalog in which the table resides. For Hive compatibility, this name is entirely lowercase.
        name(str): The name of the table for which to retrieve the definition. For Hive compatibility, this name is entirely lowercase.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.table.init.get(ctx, database_name=value, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.table.init.get database_name=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_table",
        op_kwargs={
            "CatalogId": catalog_id,
            "DatabaseName": database_name,
            "Name": name,
        },
    )


async def get_all(
    hub,
    ctx,
    database_name: str,
    catalog_id: str = None,
    expression: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the definitions of some or all of the tables in a given Database.

    Args:
        catalog_id(str, optional): The ID of the Data Catalog where the tables reside. If none is provided, the Amazon Web Services account ID is used by default. Defaults to None.
        database_name(str): The database in the catalog whose tables to list. For Hive compatibility, this name is entirely lowercase.
        expression(str, optional): A regular expression pattern. If present, only those tables whose names match the pattern are returned. Defaults to None.
        next_token(str, optional): A continuation token, included if this is a continuation call. Defaults to None.
        max_results(int, optional): The maximum number of tables to return in a single response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.table.init.get_all(ctx, database_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.table.init.get_all database_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="get_tables",
        op_kwargs={
            "CatalogId": catalog_id,
            "DatabaseName": database_name,
            "Expression": expression,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def search(
    hub,
    ctx,
    catalog_id: str = None,
    next_token: str = None,
    filters: List = None,
    search_text: str = None,
    sort_criteria: List = None,
    max_results: int = None,
    resource_share_type: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Searches a set of tables based on properties in the table metadata as well as on the parent database. You can search against text or filter conditions.  You can only get tables that you have access to based on the security policies defined in Lake Formation. You need at least a read-only access to the table for it to be returned. If you do not have access to all the columns in the table, these columns will not be searched against when returning the list of tables back to you. If you have access to the columns but not the data in the columns, those columns and the associated metadata for those columns will be included in the search.

    Args:
        catalog_id(str, optional): A unique identifier, consisting of  account_id . Defaults to None.
        next_token(str, optional): A continuation token, included if this is a continuation call. Defaults to None.
        filters(List, optional): A list of key-value pairs, and a comparator used to filter the search results. Returns all entities matching the predicate. The Comparator member of the PropertyPredicate struct is used only for time fields, and can be omitted for other field types. Also, when comparing string values, such as when Key=Name, a fuzzy match algorithm is used. The Key field (for example, the value of the Name field) is split on certain punctuation characters, for example, -, :, #, etc. into tokens. Then each token is exact-match compared with the Value member of PropertyPredicate. For example, if Key=Name and Value=link, tables named customer-link and xx-link-yy are returned, but xxlinkyy is not returned. Defaults to None.
        search_text(str, optional): A string used for a text search. Specifying a value in quotes filters based on an exact match to the value. Defaults to None.
        sort_criteria(List, optional): A list of criteria for sorting the results by a field name, in an ascending or descending order. Defaults to None.
        max_results(int, optional): The maximum number of tables to return in a single response. Defaults to None.
        resource_share_type(str, optional): Allows you to specify that you want to search the tables shared with your account. The allowable values are FOREIGN or ALL.    If set to FOREIGN, will search the tables shared with your account.    If set to ALL, will search the tables shared with your account, as well as the tables in yor local account.   . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.table.init.search(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.table.init.search
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="search_tables",
        op_kwargs={
            "CatalogId": catalog_id,
            "NextToken": next_token,
            "Filters": filters,
            "SearchText": search_text,
            "SortCriteria": sort_criteria,
            "MaxResults": max_results,
            "ResourceShareType": resource_share_type,
        },
    )


async def update(
    hub,
    ctx,
    database_name: str,
    table_input: Dict,
    catalog_id: str = None,
    skip_archive: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a metadata table in the Data Catalog.

    Args:
        catalog_id(str, optional): The ID of the Data Catalog where the table resides. If none is provided, the Amazon Web Services account ID is used by default. Defaults to None.
        database_name(str): The name of the catalog database in which the table resides. For Hive compatibility, this name is entirely lowercase.
        table_input(Dict): An updated TableInput object to define the metadata table in the catalog.
        skip_archive(bool, optional): By default, UpdateTable always creates an archived version of the table before updating it. However, if skipArchive is set to true, UpdateTable does not create the archived version. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.table.init.update(
                ctx, database_name=value, table_input=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.table.init.update database_name=value, table_input=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="update_table",
        op_kwargs={
            "CatalogId": catalog_id,
            "DatabaseName": database_name,
            "TableInput": table_input,
            "SkipArchive": skip_archive,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    user_name: str,
    path_prefix: str = None,
    marker: str = None,
    max_items: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all managed policies that are attached to the specified IAM user. An IAM user can also have inline policies embedded with it. To list the inline policies for a user, use ListUserPolicies. For information about policies, see Managed policies and inline policies in the IAM User Guide. You can paginate the results using the MaxItems and Marker parameters. You can use the PathPrefix parameter to limit the list of policies to only those matching the specified path prefix. If there are no policies attached to the specified group (or none that match the specified path prefix), the operation returns an empty list.

    Args:
        user_name(str): The name (friendly name, not ARN) of the user to list attached policies for. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        path_prefix(str, optional): The path prefix for filtering the results. This parameter is optional. If it is not included, it defaults to a slash (/), listing all policies. This parameter allows (through its regex pattern) a string of characters consisting of either a forward slash (/) by itself or a string that must begin and end with forward slashes. In addition, it can contain any ASCII character from the ! (\u0021) through the DEL character (\u007F), including most punctuation characters, digits, and upper and lowercased letters. Defaults to None.
        marker(str, optional): Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the Marker element in the response that you received to indicate where the next call should start. Defaults to None.
        max_items(int, optional): Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the IsTruncated response element is true. If you do not include this parameter, the number of items defaults to 100. Note that IAM might return fewer results, even when there are more results available. In that case, the IsTruncated response element returns true, and Marker contains a value to include in the subsequent call that tells the service where to continue from. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.attached.user_policy.list_all(ctx, user_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.attached.user_policy.list_all user_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="list_attached_user_policies",
        op_kwargs={
            "UserName": user_name,
            "PathPrefix": path_prefix,
            "Marker": marker,
            "MaxItems": max_items,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def add(hub, ctx, load_balancer_names: List, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Adds the specified tags to the specified load balancer. Each load balancer can have a maximum of 10 tags. Each tag consists of a key and an optional value. If a tag with the same key is already associated with the load balancer, AddTags updates its value. For more information, see Tag Your Classic Load Balancer in the Classic Load Balancers Guide.

    Args:
        load_balancer_names(List): The name of the load balancer. You can specify one load balancer only.
        tags(List): The tags.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elb.tags.add(ctx, load_balancer_names=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elb.tags.add load_balancer_names=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elb",
        operation="add_tags",
        op_kwargs={"LoadBalancerNames": load_balancer_names, "Tags": tags},
    )


async def describe(hub, ctx, load_balancer_names: List) -> Dict:
    r"""
    **Autogenerated function**

    Describes the tags associated with the specified load balancers.

    Args:
        load_balancer_names(List): The names of the load balancers.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elb.tags.describe(ctx, load_balancer_names=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elb.tags.describe load_balancer_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elb",
        operation="describe_tags",
        op_kwargs={"LoadBalancerNames": load_balancer_names},
    )


async def remove(hub, ctx, load_balancer_names: List, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes one or more tags from the specified load balancer.

    Args:
        load_balancer_names(List): The name of the load balancer. You can specify a maximum of one load balancer name.
        tags(List): The list of tag keys to remove.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elb.tags.remove(ctx, load_balancer_names=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elb.tags.remove load_balancer_names=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elb",
        operation="remove_tags",
        op_kwargs={"LoadBalancerNames": load_balancer_names, "Tags": tags},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def associate(
    hub,
    ctx,
    resource_share_arn: str,
    resource_arns: List = None,
    principals: List = None,
    client_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Associates the specified resource share with the specified principals and resources.

    Args:
        resource_share_arn(str): The Amazon Resource Name (ARN) of the resource share.
        resource_arns(List, optional): The Amazon Resource Names (ARN) of the resources. Defaults to None.
        principals(List, optional): The principals to associate with the resource share. The possible values are IDs of AWS accounts, and the ARNs of organizational units (OU) or organizations from AWS Organizations. Defaults to None.
        client_token(str, optional): A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ram.resource.share.init.associate(ctx, resource_share_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ram.resource.share.init.associate resource_share_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ram",
        operation="associate_resource_share",
        op_kwargs={
            "resourceShareArn": resource_share_arn,
            "resourceArns": resource_arns,
            "principals": principals,
            "clientToken": client_token,
        },
    )


async def create(
    hub,
    ctx,
    name: str,
    resource_arns: List = None,
    principals: List = None,
    tags: List = None,
    allow_external_principals: bool = None,
    client_token: str = None,
    permission_arns: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a resource share.

    Args:
        name(str): The name of the resource share.
        resource_arns(List, optional): The Amazon Resource Names (ARN) of the resources to associate with the resource share. Defaults to None.
        principals(List, optional): The principals to associate with the resource share. The possible values are IDs of AWS accounts, the ARN of an OU or organization from AWS Organizations. Defaults to None.
        tags(List, optional): One or more tags. Defaults to None.
        allow_external_principals(bool, optional): Indicates whether principals outside your AWS organization can be associated with a resource share. Defaults to None.
        client_token(str, optional): A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.
        permission_arns(List, optional): The ARNs of the permissions to associate with the resource share. If you do not specify an ARN for the permission, AWS RAM automatically attaches the default version of the permission for each resource type. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ram.resource.share.init.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ram.resource.share.init.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ram",
        operation="create_resource_share",
        op_kwargs={
            "name": name,
            "resourceArns": resource_arns,
            "principals": principals,
            "tags": tags,
            "allowExternalPrincipals": allow_external_principals,
            "clientToken": client_token,
            "permissionArns": permission_arns,
        },
    )


async def delete(hub, ctx, resource_share_arn: str, client_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified resource share.

    Args:
        resource_share_arn(str): The Amazon Resource Name (ARN) of the resource share.
        client_token(str, optional): A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ram.resource.share.init.delete(ctx, resource_share_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ram.resource.share.init.delete resource_share_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ram",
        operation="delete_resource_share",
        op_kwargs={"resourceShareArn": resource_share_arn, "clientToken": client_token},
    )


async def disassociate(
    hub,
    ctx,
    resource_share_arn: str,
    resource_arns: List = None,
    principals: List = None,
    client_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates the specified principals or resources from the specified resource share.

    Args:
        resource_share_arn(str): The Amazon Resource Name (ARN) of the resource share.
        resource_arns(List, optional): The Amazon Resource Names (ARNs) of the resources. Defaults to None.
        principals(List, optional): The principals. Defaults to None.
        client_token(str, optional): A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ram.resource.share.init.disassociate(
                ctx, resource_share_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ram.resource.share.init.disassociate resource_share_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ram",
        operation="disassociate_resource_share",
        op_kwargs={
            "resourceShareArn": resource_share_arn,
            "resourceArns": resource_arns,
            "principals": principals,
            "clientToken": client_token,
        },
    )


async def get_all(
    hub,
    ctx,
    resource_owner: str,
    resource_share_arns: List = None,
    resource_share_status: str = None,
    name: str = None,
    tag_filters: List = None,
    next_token: str = None,
    max_results: int = None,
    permission_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the resource shares that you own or the resource shares that are shared with you.

    Args:
        resource_share_arns(List, optional): The ARNs of the resource shares. Defaults to None.
        resource_share_status(str, optional): The status of the resource share. Defaults to None.
        resource_owner(str): The type of owner.
        name(str, optional): The name of the resource share. Defaults to None.
        tag_filters(List, optional): One or more tag filters. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        permission_arn(str, optional): The Amazon Resource Name (ARN) of the AWS RAM permission that is associated with the resource share. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ram.resource.share.init.get_all(ctx, resource_owner=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ram.resource.share.init.get_all resource_owner=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ram",
        operation="get_resource_shares",
        op_kwargs={
            "resourceShareArns": resource_share_arns,
            "resourceShareStatus": resource_share_status,
            "resourceOwner": resource_owner,
            "name": name,
            "tagFilters": tag_filters,
            "nextToken": next_token,
            "maxResults": max_results,
            "permissionArn": permission_arn,
        },
    )


async def update(
    hub,
    ctx,
    resource_share_arn: str,
    name: str = None,
    allow_external_principals: bool = None,
    client_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified resource share that you own.

    Args:
        resource_share_arn(str): The Amazon Resource Name (ARN) of the resource share.
        name(str, optional): The name of the resource share. Defaults to None.
        allow_external_principals(bool, optional): Indicates whether principals outside your AWS organization can be associated with a resource share. Defaults to None.
        client_token(str, optional): A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ram.resource.share.init.update(ctx, resource_share_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ram.resource.share.init.update resource_share_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ram",
        operation="update_resource_share",
        op_kwargs={
            "resourceShareArn": resource_share_arn,
            "name": name,
            "allowExternalPrincipals": allow_external_principals,
            "clientToken": client_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    deployment_config_name: str,
    minimum_healthy_hosts: Dict = None,
    traffic_routing_config: Dict = None,
    compute_platform: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Creates a deployment configuration.

    Args:
        deployment_config_name(str): The name of the deployment configuration to create.
        minimum_healthy_hosts(Dict, optional): The minimum number of healthy instances that should be available at any time during the deployment. There are two parameters expected in the input: type and value. The type parameter takes either of the following values:   HOST_COUNT: The value parameter represents the minimum number of healthy instances as an absolute value.   FLEET_PERCENT: The value parameter represents the minimum number of healthy instances as a percentage of the total number of instances in the deployment. If you specify FLEET_PERCENT, at the start of the deployment, AWS CodeDeploy converts the percentage to the equivalent number of instances and rounds up fractional instances.   The value parameter takes an integer. For example, to set a minimum of 95% healthy instance, specify a type of FLEET_PERCENT and a value of 95. Defaults to None.
        traffic_routing_config(Dict, optional): The configuration that specifies how the deployment traffic is routed. Defaults to None.
        compute_platform(str, optional): The destination platform type for the deployment (Lambda, Server, or ECS). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.deployment.config.create(
                ctx, deployment_config_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.deployment.config.create deployment_config_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="create_deployment_config",
        op_kwargs={
            "deploymentConfigName": deployment_config_name,
            "minimumHealthyHosts": minimum_healthy_hosts,
            "trafficRoutingConfig": traffic_routing_config,
            "computePlatform": compute_platform,
        },
    )


async def delete(hub, ctx, deployment_config_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a deployment configuration.  A deployment configuration cannot be deleted if it is currently in use. Predefined configurations cannot be deleted.

    Args:
        deployment_config_name(str): The name of a deployment configuration associated with the IAM user or AWS account.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.deployment.config.delete(
                ctx, deployment_config_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.deployment.config.delete deployment_config_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="delete_deployment_config",
        op_kwargs={"deploymentConfigName": deployment_config_name},
    )


async def get(hub, ctx, deployment_config_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a deployment configuration.

    Args:
        deployment_config_name(str): The name of a deployment configuration associated with the IAM user or AWS account.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.deployment.config.get(
                ctx, deployment_config_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.deployment.config.get deployment_config_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="get_deployment_config",
        op_kwargs={"deploymentConfigName": deployment_config_name},
    )


async def list_all(hub, ctx, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the deployment configurations with the IAM user or AWS account.

    Args:
        next_token(str, optional): An identifier returned from the previous ListDeploymentConfigs call. It can be used to return the next set of deployment configurations in the list. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.deployment.config.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.deployment.config.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="list_deployment_configs",
        op_kwargs={"nextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Creates a temporary set of log in credentials that you can use to log in to the Docker process on your local machine. After you're logged in, you can use the native Docker commands to push your local container images to the container image registry of your Amazon Lightsail account so that you can use them with your Lightsail container service. The log in credentials expire 12 hours after they are created, at which point you will need to create a new set of log in credentials.  You can only push container images to the container service registry of your Lightsail account. You cannot pull container images or perform any other container image management actions on the container service registry.  After you push your container images to the container image registry of your Lightsail account, use the RegisterContainerImage action to register the pushed images to a specific Lightsail container service.  This action is not required if you install and use the Lightsail Control (lightsailctl) plugin to push container images to your Lightsail container service. For more information, see Pushing and managing container images on your Amazon Lightsail container services in the Amazon Lightsail Developer Guide.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.container.service.registry_login.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.container.service.registry_login.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="create_container_service_registry_login",
        op_kwargs={},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def add(
    hub,
    ctx,
    application_name: str,
    current_application_version_id: int,
    input_id: str,
    input_processing_configuration: Dict,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds an InputProcessingConfiguration to a SQL-based Kinesis Data Analytics application. An input processor pre-processes records on the input stream before the application's SQL code executes. Currently, the only input processor available is AWS Lambda.

    Args:
        application_name(str): The name of the application to which you want to add the input processing configuration.
        current_application_version_id(int): The version of the application to which you want to add the input processing configuration. You can use the DescribeApplication operation to get the current application version. If the version specified is not the current version, the ConcurrentModificationException is returned.
        input_id(str): The ID of the input configuration to add the input processing configuration to. You can get a list of the input IDs for an application using the DescribeApplication operation.
        input_processing_configuration(Dict): The InputProcessingConfiguration to add to the application.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalyticsv2.application.input_.processing_configuration.add(
                ctx,
                application_name=value,
                current_application_version_id=value,
                input_id=value,
                input_processing_configuration=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalyticsv2.application.input_.processing_configuration.add application_name=value, current_application_version_id=value, input_id=value, input_processing_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalyticsv2",
        operation="add_application_input_processing_configuration",
        op_kwargs={
            "ApplicationName": application_name,
            "CurrentApplicationVersionId": current_application_version_id,
            "InputId": input_id,
            "InputProcessingConfiguration": input_processing_configuration,
        },
    )


async def delete(
    hub, ctx, application_name: str, current_application_version_id: int, input_id: str
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an InputProcessingConfiguration from an input.

    Args:
        application_name(str): The name of the application.
        current_application_version_id(int): The application version. You can use the DescribeApplication operation to get the current application version. If the version specified is not the current version, the ConcurrentModificationException is returned. .
        input_id(str): The ID of the input configuration from which to delete the input processing configuration. You can get a list of the input IDs for an application by using the DescribeApplication operation.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalyticsv2.application.input_.processing_configuration.delete(
                ctx, application_name=value, current_application_version_id=value, input_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalyticsv2.application.input_.processing_configuration.delete application_name=value, current_application_version_id=value, input_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalyticsv2",
        operation="delete_application_input_processing_configuration",
        op_kwargs={
            "ApplicationName": application_name,
            "CurrentApplicationVersionId": current_application_version_id,
            "InputId": input_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def add(hub, ctx, resource: Dict, lf_tags: List, catalog_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Attaches one or more tags to an existing resource.

    Args:
        catalog_id(str, optional): The identifier for the Data Catalog. By default, the account ID. The Data Catalog is the persistent metadata store. It contains database definitions, table definitions, and other control information to manage your AWS Lake Formation environment. . Defaults to None.
        resource(Dict): The resource to which to attach a tag.
        lf_tags(List): The tags to attach to the resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lakeformation.lf_tags.to_resource.add(
                ctx, resource=value, lf_tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lakeformation.lf_tags.to_resource.add resource=value, lf_tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lakeformation",
        operation="add_lf_tags_to_resource",
        op_kwargs={"CatalogId": catalog_id, "Resource": resource, "LFTags": lf_tags},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, dag_nodes: List = None, dag_edges: List = None, language: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Transforms a directed acyclic graph (DAG) into code.

    Args:
        dag_nodes(List, optional): A list of the nodes in the DAG. Defaults to None.
        dag_edges(List, optional): A list of the edges in the DAG. Defaults to None.
        language(str, optional): The programming language of the resulting code from the DAG. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glue.script.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glue.script.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glue",
        operation="create_script",
        op_kwargs={"DagNodes": dag_nodes, "DagEdges": dag_edges, "Language": language},
    )
